@@ -46,6 +46,10 @@ from .metrics import (
     ENGINE_RUNNING_PROCESSES,
     ENGINE_RUNNING_SCHEDULES,
     ENGINE_SCHEDULE_RUNNING_TIME,
+    ENGINE_EXECUTE_PRE_PROCESS_DURATION,
+    ENGINE_EXECUTE_POST_PROCESS_DURATION,
+    ENGINE_SCHEDULE_PRE_PROCESS_DURATION,
+    ENGINE_SCHEDULE_POST_PROCESS_DURATION,
     setup_gauge,
     setup_histogram,
 )
@@ -574,6 +578,7 @@ class Engine:
         root_pipeline_id: str,
         parent_pipeline_id: str,
         interrupter: ExecuteInterrupter,
+        headers: dict,
     ):
         """
         在某个进程上从某个节点开始进入推进循环
@@ -587,6 +592,7 @@ class Engine:
         :param parent_pipeline_id: 父流程 ID
         :type parent_pipeline_id: str
         """
+        engine_pre_execute_start_at = time.time()
         if interrupter.recover_point:
             logger.info(
                 "[pipeline-trace](root_pipeline: %s) recover execute with point(%s)",
@@ -626,6 +632,7 @@ class Engine:
                             node_id=process_info.destination_id,
                             root_pipeline_id=process_info.root_pipeline_id,
                             parent_pipeline_id=process_info.top_pipeline_id,
+                            headers=headers,
                         )
 
                     logger.info(
@@ -793,6 +800,9 @@ class Engine:
                     execute_result = interrupter.recover_point.execute_result
                 else:
                     handler = HandlerFactory.get_handler(node, self.runtime, interrupter)
+                    ENGINE_EXECUTE_PRE_PROCESS_DURATION.labels(type=node.type.value, hostname=self._hostname).observe(
+                        time.time() - engine_pre_execute_start_at
+                    )
                     execute_result = handler.execute(
                         process_info=process_info,
                         loop=loop,
@@ -800,6 +810,8 @@ class Engine:
                         version=version,
                         recover_point=interrupter.recover_point,
                     )
+
+                engine_post_execute_start_at = time.time()
                 interrupter.check_and_set(ExecuteKeyPoint.EXECUTE_NODE_DONE, execute_result=execute_result)
 
                 logger.info(
@@ -830,7 +842,9 @@ class Engine:
                     if execute_result.schedule_type == ScheduleType.POLL and (
                         not interrupter.recover_point or not interrupter.recover_point.set_schedule_done
                     ):
-                        self.runtime.schedule(process_id, current_node_id, schedule_id)
+                        self.runtime.schedule(
+                            process_id=process_id, node_id=current_node_id, schedule_id=schedule_id, headers=headers
+                        )
 
                     interrupter.check_and_set(ExecuteKeyPoint.EXECUTE_DONE_SET_SCHEDULE_DONE, set_schedule_done=True)
 
@@ -853,16 +867,23 @@ class Engine:
                             node_id=d.node_id,
                             root_pipeline_id=process_info.root_pipeline_id,
                             parent_pipeline_id=process_info.top_pipeline_id,
+                            headers=headers,
                         )
 
                 if execute_result.should_die:
                     self.runtime.die(process_id)
 
                 if execute_result.should_sleep or execute_result.should_die:
+                    ENGINE_EXECUTE_POST_PROCESS_DURATION.labels(type=node.type.value, hostname=self._hostname).observe(
+                        time.time() - engine_post_execute_start_at
+                    )
                     return
 
                 current_node_id = execute_result.next_node_id
                 interrupter.to_node(current_node_id)
+                ENGINE_EXECUTE_POST_PROCESS_DURATION.labels(type=node.type.value, hostname=self._hostname).observe(
+                    time.time() - engine_post_execute_start_at
+                )
 
     @setup_gauge(ENGINE_RUNNING_SCHEDULES)
     @setup_histogram(ENGINE_SCHEDULE_RUNNING_TIME)
@@ -873,6 +894,7 @@ class Engine:
         node_id: str,
         schedule_id: str,
         interrupter: ScheduleInterrupter,
+        headers: dict,
         callback_data_id: Optional[int] = None,
     ):
         """
@@ -887,6 +909,7 @@ class Engine:
         :param callback_data_id: 回调数据 ID, defaults to None
         :type callback_data_id: Optional[int], optional
         """
+        engine_pre_schedule_start_at = time.time()
         if interrupter.recover_point:
             logger.info(
                 "[pipeline-trace](schedule: %s) recover schedule with point(%s)",
@@ -991,6 +1014,7 @@ class Engine:
                     schedule_id=schedule_id,
                     callback_data_id=callback_data_id,
                     schedule_after=try_after,
+                    headers=headers,
                 )
                 return
 
@@ -1030,6 +1054,9 @@ class Engine:
                 schedule_result = interrupter.recover_point.schedule_result
             else:
                 handler = HandlerFactory.get_handler(node, self.runtime, interrupter)
+                ENGINE_SCHEDULE_PRE_PROCESS_DURATION.labels(type=node.type.value, hostname=self._hostname).observe(
+                    time.time() - engine_pre_schedule_start_at
+                )
                 schedule_result = handler.schedule(
                     process_info=process_info,
                     loop=state.loop,
@@ -1038,6 +1065,8 @@ class Engine:
                     callback_data=callback_data,
                     recover_point=interrupter.recover_point,
                 )
+
+            engine_post_schedule_start_at = time.time()
             interrupter.check_and_set(ScheduleKeyPoint.SCHEDULE_NODE_DONE, schedule_result=schedule_result)
 
             ENGINE_NODE_SCHEDULE_TIME.labels(type=type_label, hostname=self._hostname).observe(
@@ -1057,10 +1086,11 @@ class Engine:
 
             if schedule_result.has_next_schedule:
                 self.runtime.set_next_schedule(
-                    process_info.process_id,
-                    node_id,
-                    schedule_id,
-                    schedule_result.schedule_after,
+                    process_id=process_info.process_id,
+                    node_id=node_id,
+                    schedule_id=schedule_id,
+                    schedule_after=schedule_result.schedule_after,
+                    headers=headers,
                 )
 
             if schedule_result.schedule_done:
@@ -1070,8 +1100,13 @@ class Engine:
                     node_id=schedule_result.next_node_id,
                     root_pipeline_id=process_info.root_pipeline_id,
                     parent_pipeline_id=process_info.top_pipeline_id,
+                    headers=headers,
                 )
 
+            ENGINE_SCHEDULE_POST_PROCESS_DURATION.labels(type=node.type.value, hostname=self._hostname).observe(
+                time.time() - engine_post_schedule_start_at
+            )
+
     def _add_history(
         self,
         node_id: str,
