@@ -14,7 +14,7 @@ import json
 import logging
 from typing import Optional
 
-from bamboo_engine import states
+from bamboo_engine import states, metrics
 from bamboo_engine.context import Context
 from bamboo_engine.template import Template
 from bamboo_engine.handler import register_handler, NodeHandler, ExecuteResult
@@ -46,55 +46,58 @@ class ExclusiveGatewayHandler(NodeHandler):
         :return: 执行结果
         :rtype: ExecuteResult
         """
-        evaluations = [c.evaluation for c in self.node.conditions]
-        top_pipeline_id = process_info.top_pipeline_id
-        root_pipeline_id = process_info.root_pipeline_id
+        with metrics.observe(
+            metrics.ENGINE_NODE_EXECUTE_PRE_PROCESS_DURATION, type=self.node.type.value, hostname=self._hostname
+        ):
+            evaluations = [c.evaluation for c in self.node.conditions]
+            top_pipeline_id = process_info.top_pipeline_id
+            root_pipeline_id = process_info.root_pipeline_id
 
-        root_pipeline_inputs = self._get_plain_inputs(process_info.root_pipeline_id)
+            root_pipeline_inputs = self._get_plain_inputs(process_info.root_pipeline_id)
 
-        # resolve conditions references
-        evaluation_refs = set()
-        for e in evaluations:
-            refs = Template(e).get_reference()
-            evaluation_refs = evaluation_refs.union(refs)
+            # resolve conditions references
+            evaluation_refs = set()
+            for e in evaluations:
+                refs = Template(e).get_reference()
+                evaluation_refs = evaluation_refs.union(refs)
 
-        logger.info(
-            "root_pipeline[%s] node(%s) evaluation original refs: %s",
-            root_pipeline_id,
-            self.node.id,
-            evaluation_refs,
-        )
-        additional_refs = self.runtime.get_context_key_references(pipeline_id=top_pipeline_id, keys=evaluation_refs)
-        evaluation_refs = evaluation_refs.union(additional_refs)
-
-        logger.info(
-            "root_pipeline[%s] node(%s) evaluation final refs: %s",
-            root_pipeline_id,
-            self.node.id,
-            evaluation_refs,
-        )
-        context_values = self.runtime.get_context_values(pipeline_id=top_pipeline_id, keys=evaluation_refs)
-        logger.info(
-            "root_pipeline[%s] node(%s) evaluation context values: %s",
-            root_pipeline_id,
-            self.node.id,
-            context_values,
-        )
-
-        context = Context(self.runtime, context_values, root_pipeline_inputs)
-        try:
-            hydrated_context = {k: transform_escape_char(v) for k, v in context.hydrate(deformat=True).items()}
-        except Exception as e:
-            logger.exception(
-                "root_pipeline[%s] node(%s) context hydrate error",
+            logger.info(
+                "root_pipeline[%s] node(%s) evaluation original refs: %s",
                 root_pipeline_id,
                 self.node.id,
+                evaluation_refs,
             )
-            return self._execute_fail(
-                ex_data="evaluation context hydrate failed(%s), check node log for details." % e,
-                version=version,
-                ignore_boring_set=recover_point is not None,
+            additional_refs = self.runtime.get_context_key_references(pipeline_id=top_pipeline_id, keys=evaluation_refs)
+            evaluation_refs = evaluation_refs.union(additional_refs)
+
+            logger.info(
+                "root_pipeline[%s] node(%s) evaluation final refs: %s",
+                root_pipeline_id,
+                self.node.id,
+                evaluation_refs,
             )
+            context_values = self.runtime.get_context_values(pipeline_id=top_pipeline_id, keys=evaluation_refs)
+            logger.info(
+                "root_pipeline[%s] node(%s) evaluation context values: %s",
+                root_pipeline_id,
+                self.node.id,
+                context_values,
+            )
+
+            context = Context(self.runtime, context_values, root_pipeline_inputs)
+            try:
+                hydrated_context = {k: transform_escape_char(v) for k, v in context.hydrate(deformat=True).items()}
+            except Exception as e:
+                logger.exception(
+                    "root_pipeline[%s] node(%s) context hydrate error",
+                    root_pipeline_id,
+                    self.node.id,
+                )
+                return self._execute_fail(
+                    ex_data="evaluation context hydrate failed(%s), check node log for details." % e,
+                    version=version,
+                    ignore_boring_set=recover_point is not None,
+                )
 
         # check conditions
         meet_targets = []
@@ -132,37 +135,40 @@ class ExclusiveGatewayHandler(NodeHandler):
                     meet_conditions.append(c.name)
                     meet_targets.append(c.target_id)
 
-        # all miss
-        if not meet_targets and not self.node.default_condition:
-            return self._execute_fail(
-                ex_data="all conditions of branches are not meet",
-                version=version,
-                ignore_boring_set=recover_point is not None,
-            )
-        elif not meet_targets:
-            meet_targets.append(self.node.default_condition.target_id)
+        with metrics.observe(
+            metrics.ENGINE_NODE_EXECUTE_POST_PROCESS_DURATION, type=self.node.type.value, hostname=self._hostname
+        ):
+            # all miss
+            if not meet_targets and not self.node.default_condition:
+                return self._execute_fail(
+                    ex_data="all conditions of branches are not meet",
+                    version=version,
+                    ignore_boring_set=recover_point is not None,
+                )
+            elif not meet_targets:
+                meet_targets.append(self.node.default_condition.target_id)
 
-        # multiple branch hit
-        if len(meet_targets) != 1:
-            return self._execute_fail(
-                ex_data="multiple conditions meet: {}".format(meet_conditions),
+            # multiple branch hit
+            if len(meet_targets) != 1:
+                return self._execute_fail(
+                    ex_data="multiple conditions meet: {}".format(meet_conditions),
+                    version=version,
+                    ignore_boring_set=recover_point is not None,
+                )
+
+            self.runtime.set_state(
+                node_id=self.node.id,
                 version=version,
+                to_state=states.FINISHED,
+                set_archive_time=True,
                 ignore_boring_set=recover_point is not None,
             )
 
-        self.runtime.set_state(
-            node_id=self.node.id,
-            version=version,
-            to_state=states.FINISHED,
-            set_archive_time=True,
-            ignore_boring_set=recover_point is not None,
-        )
-
-        return ExecuteResult(
-            should_sleep=False,
-            schedule_ready=False,
-            schedule_type=None,
-            schedule_after=-1,
-            dispatch_processes=[],
-            next_node_id=meet_targets[0],
-        )
+            return ExecuteResult(
+                should_sleep=False,
+                schedule_ready=False,
+                schedule_type=None,
+                schedule_after=-1,
+                dispatch_processes=[],
+                next_node_id=meet_targets[0],
+            )
